#
# spec file for package graphite2
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libgraphite2-3
Name:           graphite2
Version:        1.3.1
Release:        4.4
Summary:        Font rendering capabilities for complex non-Roman writing systems
License:        LGPL-2.1+ or GPL-2.0+ or MPL-1.1
Group:          Productivity/Publishing/Word
Url:            http://sourceforge.net/projects/silgraphite/
Source0:        http://downloads.sourceforge.net/silgraphite/graphite2-%{version}.tgz
Source1:        baselibs.conf
Patch0:         graphite2-1.2.0-cmakepath.patch
Patch1:         graphite-nonvoid-return.patch
Patch2:         link-gcc-shared.diff
Patch3:         graphite2-CVE-2016-152x.patch
BuildRequires:  asciidoc
BuildRequires:  cmake
BuildRequires:  fontconfig-devel
# Required for tests
BuildRequires:  fonttools
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  pkgconfig
BuildRequires:  python-base
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Graphite2 is a project within SIL's Non-Roman Script Initiative and Language
Software Development groups to provide rendering capabilities for complex
non-Roman writing systems. Graphite can be used to create "smart fonts" capable
of displaying writing systems with various complex behaviors. With respect to
the Text Encoding Model, Graphite handles the "Rendering" aspect of writing
system implementation.

%package -n %{libname}
Summary:        Text categorization library
Group:          System/Libraries

%description -n %{libname}
Graphite2 is a project within SIL's Non-Roman Script Initiative and Language
Software Development groups to provide rendering capabilities for complex
non-Roman writing systems. Graphite can be used to create "smart fonts" capable
of displaying writing systems with various complex behaviors. With respect to
the Text Encoding Model, Graphite handles the "Rendering" aspect of writing
system implementation.

%package devel
Summary:        Files for Developing with %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       glibc-devel

%description devel
Graphite2 is a project within SIL's Non-Roman Script Initiative and Language
Software Development groups to provide rendering capabilities for complex
non-Roman writing systems. Graphite can be used to create "smart fonts" capable
of displaying writing systems with various complex behaviors. With respect to
the Text Encoding Model, Graphite handles the "Rendering" aspect of writing
system implementation.

This package contains the %{name} development files.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%patch3 

%build
%cmake \
	-DGRAPHITE2_COMPARE_RENDERER=OFF \
	-DGRAPHITE2_NTRACING=ON \
	-DCMAKE_SKIP_RPATH=OFF
# Do not use O3, from debian
find . -type f \
	-exec sed -i -e 's/\-O3//g' {} \;

make %{?_smp_mflags}

%install
%cmake_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
cd build
ctest --output-on-failure

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE COPYING
%{_bindir}/gr2fonttest

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.3*

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_includedir}/%{name}*
%{_libdir}/%{name}*

%changelog
* Thu Mar  3 2016 pgajdos@suse.com
- security update:
  * CVE-2016-1521, CVE-2016-1523, CVE-2016-1526
    [bsc#965803], [bsc#965807], [bsc#965810]
* Tue Sep  1 2015 tchvatal@suse.com
- Version bump to 1.3.1:
  * Deprecation warning: Full bidi support is about to be deprecated. Make
    contact if this impacts you.
  * Change compression block format slightly to conform to LZ4
  * Handle mono direction text with diacritics consistently. Fonts
    now see the direction they expect consistently and bidi now
    gives expected results.
  * Fixed lots of fuzz bugs
  * Coverity cleanups
  * Build now works for clang and/or asan and/or afl etc.
* Fri Aug  7 2015 tchvatal@suse.com
- Version bump to 1.3.0:
  * Various tweaks for the arabic fonts
- Added patches:
  * graphite-nonvoid-return.patch
  * graphite2-1.2.0-cmakepath.patch
- Removed patches:
  * no-specific-nunit-version.diff
  * soname.diff
* Tue May 19 2015 fstrba@suse.com
- Remove unnecessary utf-8  characters from the spec file
* Tue Oct 21 2014 dmueller@suse.com
- add link-gcc-shared.diff: link -lgcc_s to fix undefined symbols
  on various ARM architectures
* Wed Jan 29 2014 tchvatal@suse.com
- Remove harfbuzz dep. Breaks another buildcycle.
  This effectively means we are not running tests. No functional
  changes otherwise.
* Wed Jan 29 2014 tchvatal@suse.com
- Remove texlive dep to remove dep circle.
* Sun Jan 26 2014 tchvatal@suse.com
- Use rpath so the tests work.
* Sat Jan 25 2014 tchvatal@suse.com
- Enable the tests. They work on 13.1 but fail on Factory...
* Sat Jan 25 2014 tchvatal@suse.com
- Version bump to 1.2.4:
  * Various bugfixes
  * Expanded testsuite
- Remove graphite2-arm.patch - applied upstream
- Add patches from debian:
  * soname.diff
  * no-specific-nunit-version.diff
- Run^Wdocument tests and generate documentation
* Sat Jan 25 2014 tchvatal@suse.com
- Use cmake macros for nice and tidy setup.
* Fri Jun 28 2013 dimstar@opensuse.org
- Add baselibs.conf and provide libgraphite2-3-32bit, which is at
  this moment required by harfbuzz.
* Wed Nov 28 2012 crrodriguez@opensuse.org
- graphite2-arm.patch :Fix build in arm and possible other platforms, we should
  notuse -nodefaultlibs as a linker flag and let the system
  do its job automatically.
- freetype-devel should be freetype2-devel
* Tue Nov 13 2012 cfarrell@suse.com
- license update: LGPL-2.1+ or GPL-2.0+ or MPL-1.1
  See License file (most source code notices concur)
* Mon Nov 12 2012 tchvatal@suse.com
- Whitespace trying to figure out why spec file is interpreted as
  binary.
* Fri Nov  9 2012 tchvatal@suse.com
- Fix desc not to mention libexttextcat.
* Tue Nov  6 2012 tchvatal@suse.com
- Initial commit version 1.2.0.
